@@ -2,7 +2,7 @@
 #' 
 #' @usage NULL
 #' @name mlr_pipeops_explicit_pta
-#' @format [R6Class] object inheriting from [`PipeOpTaskPreproc`]/[`PipeOp`].
+#' @format \link[R6:R6Class]{R6::R6Class} object inheriting from \link[mlr3pipelines:PipeOpTaskPreproc]{mlr3pipelines::PipeOpTaskPreproc}/\link[mlr3pipelines:PipeOp]{mlr3pipelines::PipeOp}.
 #'
 #' @description
 #'   Turns the column with column role 'pta' into an explicit separate column prefixed with ".._internal_pta_".
@@ -16,15 +16,14 @@
 #' * `param_vals` (`list()`)
 #' 
 #' @section Input and Output Channels:
-#' Input and output channels are inherited from [PipeOpTaskPreproc]. Instead of a [Task][mlr3::Task], a
-#' [TaskClassif][mlr3::TaskClassif] is used as input and output during training and prediction.
+#' Input and output channels are inherited from [mlr3pipelines::PipeOpTaskPreproc]. Instead of a [mlr3::Task], a
+#' [mlr3::TaskClassif] is used as input and output during training and prediction.
 #'
-#' The output during training is the input [Task][mlr3::Task] with added weights column according
+#' The output during training is the input [mlr3::Task] with added weights column according
 #' to target class. The output during prediction is the unchanged input.
 #'
-#
 #' @section State:
-#' The `$state` is a named `list` with the `$state` elements inherited from [PipeOpTaskPreproc][mlr3pipelines::PipeOpTaskPreproc].
+#' The `$state` is a named `list` with the `$state` elements inherited from [mlr3pipelines::PipeOpTaskPreproc].
 #'
 #' @section Parameters:
 #' The PipeOp does not have any hyperparameters.
@@ -33,10 +32,10 @@
 #' Copies the existing pta column to a new column.
 #' 
 #' @section Fields:
-#' Only fields inherited from [PipeOpTaskPreproc]/[`PipeOp`].
+#' Only fields inherited from [mlr3pipelines::PipeOpTaskPreproc]/[mlr3pipelines::PipeOp].
 #'
 #' @section Methods:
-#' Methods inherited from [PipeOpTaskPreproc][mlr3pipelines::PipeOpTaskPreproc]/[PipeOp][mlr3pipelines::PipeOp].
+#' Methods inherited from [mlr3pipelines::PipeOpTaskPreproc]/[mlr3pipelines::PipeOp].
 #' 
 #' @family PipeOps
 #' @seealso https://mlr3book.mlr-org.com/list-pipeops.html
@@ -47,10 +46,10 @@
 #' epta = po("explicit_pta")
 #' new = epta$train(list(tsk("adult_train")))
 PipeOpExplicitPta = R6Class("PipeOpExplicitPta",
-  inherit = PipeOpTaskPreproc,
+  inherit = mlr3pipelines::PipeOpTaskPreproc,
   public = list(
     #' @description
-    #' Creates a new instance of this [R6][R6::R6Class][PipeOp] R6 class.
+    #' Creates a new instance of this [R6::R6Class][mlr3pipelines::PipeOpTaskPreproc] R6 class.
     #'
     #' @param id `character` \cr
     #'   The PipeOps identifier in the PipeOps library.
