@@ -2,19 +2,19 @@
 #'
 #' @usage NULL
 #' @name mlr_pipeops_reweighing
-#' @format [R6Class] object inheriting from [`PipeOpTaskPreproc`]/[`PipeOp`].
+#' @format \link[R6:R6Class]{R6::R6Class} object inheriting from \link[mlr3pipelines:PipeOpTaskPreproc]{mlr3pipelines::PipeOpTaskPreproc}/\link[mlr3pipelines:PipeOp]{mlr3pipelines::PipeOp}.
 #'
 #' @description
 #' Adjusts class balance and protected group balance in order to achieve fair(er) outcomes.
 #'
 #' @section PipeOpReweighingWeights:
-#' Adds a class weight column to the [Task][mlr3::Task] that different [`Learner`][mlr3::Learner]s
+#' Adds a class weight column to the [mlr3::Task] that different [mlr3::Learner]s
 #' may be using. In case initial weights are present, those are multiplied with new weights.
 #' Caution: Only fairness tasks are supported. Which means tasks need to have protected field.
 #' `tsk$col_roles$pta`.
 #'
 #' @section PipeOpReweighingOversampling:
-#' Oversamples a [Task][mlr3::Task] for more balanced ratios in subgroups and protected groups.
+#' Oversamples a [mlr3::Task] for more balanced ratios in subgroups and protected groups.
 #' Can be used if a learner does not support weights.
 #' Caution: Only fairness tasks are supported. Which means tasks need to have protected field.
 #' `tsk$col_roles$pta`.
@@ -30,36 +30,36 @@
 #' * `param_vals` (`list()`)
 #'
 #' @section Input and Output Channels:
-#' Input and output channels are inherited from [PipeOpTaskPreproc]. Instead of a [`Task`][mlr3::Task], a
-#' [TaskClassif][mlr3::TaskClassif] is used as input and output during training and prediction.
+#' Input and output channels are inherited from [mlr3pipelines::PipeOpTaskPreproc]. Instead of a [mlr3::Task], a
+#' [mlr3::TaskClassif] is used as input and output during training and prediction.
 #'
-#' The output during training is the input [Task][mlr3::Task] with added weights column according
+#' The output during training is the input [mlr3::Task] with added weights column according
 #' to target class. The output during prediction is the unchanged input.
 #'
 #' @section State:
-#' The `$state` is a named `list` with the `$state` elements inherited from [PipeOpTaskPreproc].
+#' The `$state` is a named `list` with the `$state` elements inherited from [mlr3pipelines::PipeOpTaskPreproc].
 #'
 #' @section Parameters:
 #'  * `alpha` (`numeric()`): A number between 0 (no debiasing) and 1 (full debiasing).
 #'
 #' @section Internals:
-#' Introduces, or overwrites, the "weights" column in the [Task][mlr3::Task].
-#' However, the [Learner][mlr3::Learner] method needs to
+#' Introduces, or overwrites, the "weights" column in the [mlr3::Task].
+#' However, the [mlr3::Learner] method needs to
 #' respect weights for this to have an effect.
 #'
 #' The newly introduced column is named `reweighing.WEIGHTS`; there will be a naming conflict if this
 #' column already exists and is *not* a weight column itself.
 #'
 #' @section Fields:
-#' Only fields inherited from [PipeOpTaskPreproc]/[`PipeOp`].
+#' Only fields inherited from [mlr3pipelines::PipeOpTaskPreproc]/[mlr3pipelines::PipeOp].
 #'
 #' @section Methods:
-#' Methods inherited from [PipeOpTaskPreproc]/[`PipeOp`].
+#' Methods inherited from [mlr3pipelines::PipeOpTaskPreproc]/[mlr3pipelines::PipeOp].
 #'
 #' @family PipeOps
 #' @seealso https://mlr3book.mlr-org.com/list-pipeops.html
 #' @export
-#' @examples
+#' @examplesIf rlang::is_installed("rpart")
 #' library("mlr3")
 #' library("mlr3pipelines")
 #'
@@ -76,7 +76,7 @@ PipeOpReweighingWeights = R6Class("PipeOpReweighingWeights",
   inherit = mlr3pipelines::PipeOpTaskPreproc,
   public = list(
     #' @description
-    #' Creates a new instance of this [R6][R6::R6Class][PipeOp] R6 class.
+    #' Creates a new instance of this [R6::R6Class][mlr3pipelines::PipeOpTaskPreproc] R6 class.
     #'
     #' @param id `character` \cr
     #'   The PipeOps identifier in the PipeOps library.
@@ -113,20 +113,19 @@ PipeOpReweighingWeights = R6Class("PipeOpReweighingWeights",
       wtab = compute_reweighing_weights(task, 1)
       wcol = task$data(cols = c(task$backend$primary_key, task$target_names, task$col_roles$pta))
       wcol = wcol[wtab, on = c(task$target_names, task$col_roles$pta)][, c(task$backend$primary_key, "wt"), with = FALSE]
-      if (is.null(task$weights)) {
+      if (is.null(task$weights_learner)) {
         initial_weights = rep(1, task$nrow)
       } else {
-        initial_weights = task$weights[wcol]$weight
+        initial_weights = task$weights_learner[wcol]$weight
       }
       wcol = wcol[, wt := wt * initial_weights]
       setnames(wcol, c(task$backend$primary_key, weightcolname))
       task$cbind(wcol)
 
-      if (length(task$col_roles$weight)) {
-        task$set_col_roles(task$col_roles$weight, remove_from = "weight")
+      if (length(task$col_roles$weights_learner)) {
+        task$set_col_roles(task$col_roles$weights_learner, remove_from = "weights_learner")
       }
-
-      task$set_col_roles(weightcolname, "weight")
+      task$set_col_roles(weightcolname, "weights_learner")
       task
     },
 
