@@ -1,10 +1,10 @@
 #' Score weights per group (indicated by 'pta')
 #'
-#' @param prediction [Prediction] A prediction
-#' @param base_measure [Measure] The measure to compute in each group.
-#' @param task [Task] the task prediction was made on.
-#' @param ... `any` passed on to respective measure.
-#' @return [numeric] Computed score
+#' @param prediction [mlr3::Prediction] A prediction
+#' @param base_measure [mlr3::Measure] The measure to compute in each group.
+#' @param task [mlr3::Task] the task prediction was made on.
+#' @param ... any passed on to respective measure.
+#' @return numeric Computed score
 #'
 #' @noRd
 score_groupwise = function(prediction, base_measure, task, ...) {
@@ -13,14 +13,16 @@ score_groupwise = function(prediction, base_measure, task, ...) {
 
   # Split prediction
   map_dbl(split(prediction$row_ids, groups), function(rws) {
-    prediction$clone()$filter(rws)$score(base_measure, task = task, ...)
+    args = list(...)
+    args$weights = NULL
+    invoke(prediction$clone()$filter(rws)$score, base_measure, task = task, .args = args)
   })
 }
 
 #' Compute weights for PipeOpReweighing*
 #'
-#' @param task [Task] the task
-#' @param alpha [numeric] Debiasing strength
+#' @param task [mlr3::Task] the task
+#' @param alpha numeric Debiasing strength
 #'
 #' @return [data.table] A data.table with counts and weights for each feature.
 #' @noRd
@@ -45,10 +47,10 @@ compute_reweighing_weights = function(task, alpha = 1) {
 
 #' Same as task$filter(), but allows duplicate row IDs
 #'
-#' @param task [Task] the task
+#' @param task [mlr3::Task] the task
 #' @param row_ids [numeric] the row IDs to select
 #'
-#' @return [Task] the modified task
+#' @return [mlr3::Task] the modified task
 #' @noRd
 task_filter_ex = function(task, row_ids) {
   added_rows = row_ids[duplicated(row_ids)]
@@ -118,9 +120,9 @@ int_to_numeric = function(p) {
 
 #' Score weights per group (indicated by 'pta')
 #'
-#' @param task [Task]
+#' @param task [mlr3::Task]
 #' @param rows (`integer`) rows to get
-#' @param intersect (`logical`) should groups be intersected? 
+#' @param intersect (`logical`) should groups be intersected?
 #'   If `TRUE` all pta columns are combined into a single column factor.
 #'   If `FALSE`, returns all pta columns converted to factors.
 #' @return data.table vector of group assignments.
@@ -137,7 +139,7 @@ get_pta = function(task, rows = NULL, intersect = FALSE) {
 
 #' @title Task summary for fairness report
 #'
-#' @description 
+#' @description
 #' Create the general task documentation in a dataframe for fairness report.
 #' The information includes
 #' * Audit Date
@@ -148,7 +150,7 @@ get_pta = function(task, rows = NULL, intersect = FALSE) {
 #' * Feature Names
 #' * The Protected Attribute
 #'
-#' @param task [Task]
+#' @param task [mlr3::Task]
 #' @return 
 #' `data.frame` containing the reported information
 #' @examples
